Rename instrumentation ExceptionCaught to ExceptionThrown

The instrumentation ExceptionCaught event was badly named since it is
actually sent at the time the exception is thrown and is sent even if
the exception is never actually caught. Rename it and associated
methods/fields to ExceptionThrown to more accurately reflect the
event's semantics.

Test: ./test.py --host -j50
Change-Id: I1e9c401ab619259b25928dbf19f62d3fa9573d47
diff --git a/openjdkjvmti/events.cc b/openjdkjvmti/events.cc
index 2944a45..73e6881 100644
--- a/openjdkjvmti/events.cc
+++ b/openjdkjvmti/events.cc
@@ -538,8 +538,8 @@
     }
   }
 
-  // Call-back when an exception is caught.
-  void ExceptionCaught(art::Thread* self ATTRIBUTE_UNUSED,
+  // Call-back when an exception is thrown.
+  void ExceptionThrown(art::Thread* self ATTRIBUTE_UNUSED,
                        art::Handle<art::mirror::Throwable> exception_object ATTRIBUTE_UNUSED)
       REQUIRES_SHARED(art::Locks::mutator_lock_) OVERRIDE {
     return;